@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/Adm/SyL_AdmFlow.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlowVew.php,v 1.2 2007/08/08 12:25:20 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmFlowVew extends SyL_AdmFlow
@@ -82,7 +82,7 @@ class SyL_AdmFlowVew extends SyL_AdmFlow
         $key_name = $form->getStructConfig('key_name');
         // ѥ᡼
         $key = $data->get($key_name);
-        if (!is_string($key)) {
+        if (($key === null) || ($key === '')) {
             // Բ
             SyL_Response::redirect($this->getUrl('lst'));
         }
@@ -127,6 +127,8 @@ class SyL_AdmFlowVew extends SyL_AdmFlow
         $data->set('page', $data->get('page'));
         $data->set('sort', $data->get('sort'));
 
+        // ǧɽϢ
+        $data->set('view_alert', $form->getStructConfig('view_alert'));
         // ʸϢ
         $data->set('title', $form->getStructConfig('title'));
 
