@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.3 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.3 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationLst extends SyL_AdmOperation
@@ -86,7 +86,26 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
         // ڡ󥻥å
         $this->dao->setPage($page, $limit);
         // ɽǡ
-        return $this->dao->select($tables, $this->relation);
+        $results = $this->dao->select($tables, $this->relation);
+        
+        $options = array();
+        foreach (array_keys($this->dao->getSelectHeaders()) as $name) {
+            $options[$name] = $this->form->getOption($name);
+        }
+
+        $cnt = count($results);
+        for ($i=0; $i<$cnt; $i++) {
+            foreach ($results[$i] as $name => $value) {
+                if ($options[$name] !== null) {
+                    if (isset($options[$name][$value])) {
+                        $results[$i][$name] = $options[$name][$value];
+                    } else {
+                        $results[$i][$name] = '';
+                    }
+                }
+            }
+        }
+        return $results;
     }
 
     /**
