@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationNew.php,v 1.1 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationNew.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,39 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationNew.php,v 1.1 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationNew.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationNew extends SyL_AdmOperation
 {
+    /**
+     * 饹Υץѥƥơ֥ȴϢ
+     *
+     * @access public
+     */
+    function loadConfig()
+    {
+        parent::loadConfig();
+
+        // ǡޥǡ
+        $data_sources = $this->form->getDataSources();
+        foreach ($data_sources as $name => $data_source) {
+            // ơ֥륪֥ȼ
+            $table =& $this->tables[$data_source['alias']];
+            $table->addColumn($data_source['name']);
+            $table->addColumn($data_source['value']);
+            // ¸options
+            if (!isset($this->form->elements_config[$name]['options'])) {
+                $this->form->elements_config[$name]['options'] = array();
+            }
+            foreach ($this->dao->select($table) as $values) {
+                $column_name  = current($values);
+                $column_value = next($values);
+                $this->form->elements_config[$name]['options'][$column_value] = $column_name;
+            }
+        }
+    }
+
     /**
      * ϿԤ
      *
