@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlow.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlow.php,v 1.3 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -52,10 +52,10 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Adm.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmFlow.php,v 1.2 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmFlow.php,v 1.3 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_AdmFlow
+class SyL_AdmFlow extends AppAction
 {
     /**
      * ١URL
@@ -110,17 +110,6 @@ class SyL_AdmFlow
         return SyL_ActionForm::factory($this->classname, '', $this->opp_name);
     }
 
-    /**
-     * DB֥Ȥ
-     *
-     * @access public
-     * @return object DB֥
-     */
-    function &getDB()
-    {
-        return SyL_DB::getConnection();
-    }
-
     /**
      * ١URL򥻥åȤ
      *
