@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthBasic.php,v 1.3 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthBasic.php,v 1.4 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,19 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthBasic.php,v 1.3 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthBasic.php,v 1.4 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AuthBasic extends SyL_Auth
 {
+    /**
+     * ١åǧڤʸ
+     *
+     * @access private
+     * @var string
+     */
+    var $realm = 'SyL Authentication Area';
+
     /**
      * 󥢥Ƚ
      * 
@@ -52,15 +60,35 @@ class SyL_AuthBasic extends SyL_Auth
      */
     function isLoginAction()
     {
-        if (isset($_SERVER['PHP_AUTH_USER'])) {
+        // å
+        if ($this->isLogin()) {
+            return false;
+        }
+
+        // ѥ᡼Ƚ
+        if (isset($_SERVER['PHP_AUTH_USER']) && ($_SERVER['PHP_AUTH_USER'] !== '')) {
             return true;
         }
-        SyL_Response::setHeader('WWW-Authenticate', 'Basic realm="SyL Authentication Area"');
-        SyL_Response::setStatusHeader('401');
-        $response =& SyL_Response::singleton();
-        $response->display($view);
 
-        trigger_error("[SyL error] Basic Authentication canceled", E_USER_ERROR);
+        // ١åǧɽ
+        SyL_Response::setHeader('WWW-Authenticate', 'Basic realm="' . $this->realm . '"');
+        SyL_Response::setStatusHeader('401');
+
+        $version = SYL_VERSION;
+        $redirect_url = call_user_func(array(__CLASS__, 'getAuthSessionErrorUrl'));
+        $data = <<<HTML
+<html>
+<head>
+<meta http-equiv="Refresh" content="0;URL={$redirect_url}?login=false">
+<title>401 authorization required (SyL Framework {$version})</title>
+</head>
+<body>
+</body>
+</html>
+HTML;
+
+        $response =& SyL_Response::singleton();
+        $response->display($data);
         exit;
     }
 
@@ -72,15 +100,21 @@ class SyL_AuthBasic extends SyL_Auth
      */
     function doLogin()
     {
-         $_SERVER['REQUEST_METHOD'] = 'POST';
-         $_POST[$this->username] = isset($_SERVER['PHP_AUTH_USER']) ? $_SERVER['PHP_AUTH_USER'] : '';
-         $_POST[$this->password] = isset($_SERVER['PHP_AUTH_PW'])   ? $_SERVER['PHP_AUTH_PW']   : '';
+        // REQUEST_METHODŪѹ
+        $request_method = $_SERVER['REQUEST_METHOD'];
+
+        $_SERVER['REQUEST_METHOD'] = 'POST';
+        $_POST[$this->username] = isset($_SERVER['PHP_AUTH_USER']) ? $_SERVER['PHP_AUTH_USER'] : '';
+        $_POST[$this->password] = isset($_SERVER['PHP_AUTH_PW'])   ? $_SERVER['PHP_AUTH_PW']   : '';
 
         list(,$type) = explode(':', SYL_AUTH_TYPE, 2);
-        $auth = SyL_Auth::createAuth($type);
+        $auth =& SyL_Auth::singleton($type);
         $auth->setUserParamaterName($this->username);
         $auth->setPasswordParamaterName($this->password);
-        return $auth->doLogin();
+        $result = $auth->doLogin();
+
+        $_SERVER['REQUEST_METHOD'] = $request_method;
+        return $result;
     }
 }
 
