@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthDB.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthDB.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,22 +44,11 @@ require_once SYL_INCLUDE_DIR . '/lib/SyL_DB.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AuthDB.php,v 1.2 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AuthDB.php,v 1.3 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AuthDB extends SyL_Auth
 {
-    /**
-     * 󥢥Ƚ
-     * 
-     * @access public
-     * @return bool true: 󥢥󤢤ꡢfalse: 󥢥ʤ
-     */
-    function isLoginAction()
-    {
-        return (($_SERVER['REQUEST_METHOD'] == 'POST') && isset($_POST[$this->username]) && isset($_POST[$this->password]));
-    }
-
     /**
      * ǧڼ¹
      * 
@@ -71,11 +60,12 @@ class SyL_AuthDB extends SyL_Auth
          $client_username = isset($_POST[$this->username]) ? $_POST[$this->username] : '';
          $client_password = isset($_POST[$this->password]) ? $_POST[$this->password] : '';
 
-         $parameters = explode(':', SYL_AUTH_TYPE_PARAMETER, 5);
+         $parameters = explode(':', SYL_AUTH_TYPE_PARAMETER, 4);
          if (!isset($parameters[3])) $parameters[3] = '';
-         if (!isset($parameters[4])) $parameters[4] = '';
 
-         $conn =& SyL_DB::getConnection(SYL_DB_DSN);
+         $conn =& SyL_DB::getConnection();
+
+         SyL_Loggers::info("[Auth] Table: {$parameters[0]} Column(ID): {$parameters[1]} Column(Password): {$parameters[2]}");
 
          $sql  = "";
          $sql .= "SELECT ";
@@ -84,14 +74,14 @@ class SyL_AuthDB extends SyL_Auth
          $sql .=   $parameters[0] . " ";
          $sql .= "WHERE ";
          $sql .=   $parameters[1] . " = '" . $conn->escape($client_username) . "' ";
-         if ($parameters[4]) {
-         $sql .=   " AND " . $parameters[4] . " ";
+         if ($parameters[3]) {
+         $sql .=   " AND " . $parameters[3] . " ";
          }
 
          $conn->queryRef($sql, $server_password, 'one');
 
          // ѥȽ
-         return $this->isLoginPassword($client_username, $client_password, $server_password, (bool)$parameters[3]);
+         return $this->isLoginPassword($client_username, $client_password, $server_password);
     }
 }
 
