@@ -27,11 +27,20 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.22 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.23 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
+/**
+ * 󥯥饹
+ */
+require_once SYL_INCLUDE_DIR . '/framework/SyL_Action.php';
+/**
+ * ץꥱ̥󥯥饹
+ */
+require_once SYL_APP_DIR . '/AppAction.php';
+
 /**
  * եɤ߹९饹
  *
@@ -39,7 +48,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigActions.php,v 1.22 2007/06/24 10:44:50 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigActions.php,v 1.23 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigActions extends SyL_Config
@@ -47,10 +56,17 @@ class SyL_ConfigActions extends SyL_Config
     /**
      * ٥̾
      * 
-     * @access private
+     * @access protected
      * @var string
      */
     var $event = 'executeStream';
+    /**
+     * ǥեȼ¹Խ
+     * 
+     * @access protected
+     * @param int
+     */
+    var $default_priority = 5;
     /**
      * ƥʥ̾
      * 
@@ -58,13 +74,6 @@ class SyL_ConfigActions extends SyL_Config
      * @var object
      */
     var $action_key = SYL_ACTION_KEY;
-    /**
-     * ǥեȼ¹Խ
-     * 
-     * @access private
-     * @param int
-     */
-    var $default_priority = 5;
     /**
      * ǥեȥƥץ졼ȥ
      * 
@@ -86,25 +95,6 @@ class SyL_ConfigActions extends SyL_Config
      * @var array
      */
     var $action_cache_value = array();
-    /**
-     * ǡ֥
-     * 
-     * @access private
-     * @var object
-     */
-    var $context = null;
-
-    /**
-     * ȥ򥻥å
-     * С饤
-     *
-     * @access public
-     * @param object ȥ饪֥
-     */
-    function setController(&$controller)
-    {
-        $this->context =& $controller->container->getComponent('context');
-    }
 
     /**
      * XMLեβϽ
@@ -115,7 +105,7 @@ class SyL_ConfigActions extends SyL_Config
     {
         if (SYL_CACHE) {
             // åѤ
-            $key = $this->context->getActionDir() . $this->context->getActionFile() . $this->context->getActionName();
+            $key = SYL_APP_DIR . $this->context->getActionFile() . $this->context->getActionName();
             $cache =& $this->getCache($key);
             if ($cache) {
                 // å夬Ǥʤäʥå奪֥Ȥ
@@ -164,13 +154,16 @@ class SyL_ConfigActions extends SyL_Config
      */
     function getElement($current_path, $attribute, $text)
     {
-        static $name                = '';
-        static $pre_name            = '';
-        static $post_name           = '';
-        static $component_name      = '';
-        static $method_name         = '';
-        static $prepost_method_name = '';
-        static $load                = false;
+        static $name             = '';
+        static $pre_name         = '';
+        static $post_name        = '';
+
+        static $method_name      = '';
+        static $pre_method_name  = '';
+        static $post_method_name = '';
+
+        static $component_name   = '';
+        static $load             = false;
 
 //echo $current_path . "<br>";
         // 1ɺѤߤξʹߥå
@@ -192,55 +185,48 @@ class SyL_ConfigActions extends SyL_Config
             $reg = isset($attribute['path']) ? str_replace('/', '\\/', $attribute['path']) : '(.*)';
             if (preg_match('/^' . $reg . '$/', $this->context->getActionFile(), $matches)) {
                 $name = $this->action_key;
-                $this->config[$name]['class']     = $this->context->getClassName();
-                $this->config[$name]['type']      = 'action';
-                $this->config[$name]['file']      = $this->context->getActionDir() . $this->context->getActionFile();
-                $this->config[$name]['reference'] = true;
-                // ¹Խ
-                $this->config[$name]['priority'] = $this->default_priority;
-                // 󥹥ȥ饯󥸥ե饰
-                $this->config[$name]['constructor'] = false;
-                // ե뤬¸ߤʤȥ顼Υե饰
-                $this->config[$name]['force'] = (SYL_ENV_TYPE == 'cmd'); // ޥɥ饤Τߥե¸ߥå
+                // ݡͥȥѥ᡼
+                $this->config[$name] = array(
+                    'class'       => $this->context->getClassName(),
+                    'type'        => 'action',
+                    'file'        => $this->context->getActionDir() . $this->context->getActionFile(),
+                    'reference'   => true,
+                    'priority'    => $this->default_priority, // ¹Խ
+                    'constructor' => false, // 󥹥ȥ饯󥸥ե饰
+                    'force'       => (SYL_ENV_TYPE == 'cmd'), // ե뤬¸ߤʤȥ顼Υե饰 ޥɥ饤Τߥե¸ߥå
+                    'args'        => array() // 
+                );
+
+                // ̥
+                $pre_name = 'pre_' . $name;
+                $this->config[$pre_name] = $this->config[$name];
+                $this->config[$pre_name]['priority']--; // ¹Խ(1ʳᤤ)
+                $this->config[$pre_name]['event'][$this->event][] = $pre_name;
+
+                // ̥
+                $post_name = 'post_' . $name;
+                $this->config[$post_name] = $this->config[$name];
+                $this->config[$post_name]['priority']++; // ¹Խ(1ʳ٤)
+                $this->config[$post_name]['event'][$this->event][] = $post_name;
+
+                // ե뤬̵硢pre, postΤ߼¹
+                if (!is_file($this->context->getActionDir() . $this->context->getActionFile())) {
+                    $this->config[$pre_name]['file']   = SYL_APP_DIR . '/AppAction.php';
+                    $this->config[$pre_name]['class']  = 'AppAction';
+                    $this->config[$post_name]['file']  = SYL_APP_DIR . '/AppAction.php';
+                    $this->config[$post_name]['class'] = 'AppAction';
+                }
+
                 // ٥ȥʥ֥Ⱥ
                 $this->config[$name]['event'][$this->event][] = $name;
-                // 
-                $this->config[$name]['args'] = array();
-                // ӥ塼
-                $this->action_cache_value['viewType'] = isset($attribute['viewType']) ? $attribute['viewType'] : '';
-                // 쥤
-                $this->action_cache_value['layout'] = isset($attribute['layout']) ? $attribute['layout'] : '';
-                // ޥӥ塼
-                $this->action_cache_value['customizedViewFile']  = isset($attribute['customizedViewFile'])  ? $attribute['customizedViewFile']  : '';
-                $this->action_cache_value['customizedViewClass'] = isset($attribute['customizedViewClass']) ? $attribute['customizedViewClass'] : '';
 
-                // ̥
-                if (isset($attribute['commonPreAction']) && $attribute['commonPreAction']) {
-                    $pre_name = 'commonPreAction';
-                    $this->config[$pre_name]['class']       = $attribute['commonPreAction'];
-                    $this->config[$pre_name]['type']        = 'action';
-                    $this->config[$pre_name]['file']        = SYL_APP_DIR . '/' .  $attribute['commonPreAction'] . '.php';
-                    $this->config[$pre_name]['reference']   = true;
-                    $this->config[$pre_name]['priority']    = $this->default_priority - 1; // ¹Խ(1ʳᤤ)
-                    $this->config[$pre_name]['constructor'] = false;
-                    $this->config[$pre_name]['force']       = false;
-                    $this->config[$pre_name]['event'][$this->event][] = $pre_name;
-                    $this->config[$pre_name]['args'] = array();
-                }
-
-                // ̥
-                if (isset($attribute['commonPostAction']) && $attribute['commonPostAction']) {
-                    $post_name = 'commonPostAction';
-                    $this->config[$post_name]['class']       = $attribute['commonPostAction'];
-                    $this->config[$post_name]['type']        = 'action';
-                    $this->config[$post_name]['file']        = SYL_APP_DIR . '/' .  $attribute['commonPostAction'] . '.php';
-                    $this->config[$post_name]['reference']   = true;
-                    $this->config[$post_name]['priority']    = $this->default_priority + 1; // ¹Խ(1ʳ٤)
-                    $this->config[$post_name]['constructor'] = false;
-                    $this->config[$post_name]['force']       = false;
-                    $this->config[$post_name]['event'][$this->event][] = $post_name;
-                    $this->config[$post_name]['args'] = array();
-                }
+                // ݡͥȥѥ᡼ʳ
+                $this->action_cache_value = array(
+                    'viewType' => isset($attribute['viewType']) ? $attribute['viewType'] : '', // ӥ塼
+                    'layout'   => isset($attribute['layout'])   ? $attribute['layout']   : '', // 쥤
+                    'customizedViewFile'  => isset($attribute['customizedViewFile'])  ? $attribute['customizedViewFile']  : '', // ޥӥ塼
+                    'customizedViewClass' => isset($attribute['customizedViewClass']) ? $attribute['customizedViewClass'] : ''
+                );
 
                 // ǥեȥƥץ졼ȼ
                 if ((SYL_ENV_TYPE == 'web') && isset($attribute['template'])) {
@@ -270,18 +256,17 @@ class SyL_ConfigActions extends SyL_Config
                 break;
 
             case '/syl-actions/action/method':
-                $method_name         = 'method:' . str_replace('{$action}', $this->context->getActionName(), $attribute['name']);
-                $prepost_method_name = 'method:' . str_replace('{$action}', '', $attribute['name']);
+                $method_name = 'method:' . str_replace('{$action}', $this->context->getActionName(), $attribute['name']);
                 $this->config[$name]['args'][$method_name] = array();
                 $this->config[$name]['event'][$this->event][] = $method_name; // ٥ȥ
-                if ($pre_name) {
-                    $this->config[$pre_name]['args'][$prepost_method_name] = array();
-                    $this->config[$pre_name]['event'][$this->event][]      = $prepost_method_name; // ٥ȥ
-                }
-                if ($post_name) {
-                    $this->config[$post_name]['args'][$prepost_method_name] = array();
-                    $this->config[$post_name]['event'][$this->event][]      = $prepost_method_name; // ٥ȥ
-                }
+
+                $pre_method_name = 'method:preExecute';
+                $this->config[$pre_name]['args'][$pre_method_name] = array();
+                $this->config[$pre_name]['event'][$this->event][]  = $pre_method_name; // ٥ȥ
+
+                $post_method_name = 'method:postExecute';
+                $this->config[$post_name]['args'][$post_method_name] = array();
+                $this->config[$post_name]['event'][$this->event][]   = $post_method_name; // ٥ȥ
                 break;
 
             case '/syl-actions/action/setter/arg':
@@ -289,15 +274,9 @@ class SyL_ConfigActions extends SyL_Config
                 $type = isset($attribute['type']) ? $attribute['type'] : 'value';
                 $ref  = (isset($attribute['reference']) && ($attribute['reference'] === 'true')) ? 'true' : 'false';
                 $arg  = "{$type}:{$ref}:{$text}";
-                $this->config[$name]['args'][$method_name][] = $arg;
-                if ($prepost_method_name) {
-                    if ($pre_name) {
-                        $this->config[$pre_name]['args'][$prepost_method_name][] = $arg;
-                    }
-                    if ($post_name) {
-                        $this->config[$post_name]['args'][$prepost_method_name][] = $arg;
-                    }
-                }
+                $this->config[$name]['args'][$method_name][]           = $arg;
+                $this->config[$pre_name]['args'][$pre_method_name][]   = $arg;
+                $this->config[$post_name]['args'][$post_method_name][] = $arg;
                 break;
 
            case '/syl-actions/action/components/component':
