@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.16 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,22 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.15 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigDefines.php,v 1.16 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigDefines extends SyL_Config
 {
+    /**
+     * ƥȤ򥻥å
+     * ƥȤʤΤ
+     *
+     * @access protected
+     * @param object ȥ饪֥
+     */
+    function setContext(&$controller)
+    {
+    }
+
     /**
      * XMLեβϽ
      *
@@ -53,7 +64,7 @@ class SyL_ConfigDefines extends SyL_Config
     {
         if (SYL_CACHE) {
             // åѤ
-            $key = implode('', $this->file_names);
+            $key = SYL_APP_DIR;
             $cache =& $this->getCache($key);
             if ($cache) {
                 // å夬Ǥʤäʥå奪֥Ȥ
