@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.10 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.11 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -46,7 +46,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.10 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ControllerCmd.php,v 1.11 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ControllerCmd extends SyL_Controller
@@ -74,7 +74,7 @@ class SyL_ControllerCmd extends SyL_Controller
     {
         $config_files = array();
         // ץꥱե륿ե
-        $filter = SYL_APP_DIR . "/{$this->filter_file_name}";
+        $filter = SYL_APP_CONFIG_DIR . "/{$this->filter_file_name}";
         if (file_exists($filter)) {
             $config_files['filters'][] = $filter;
         }
@@ -97,7 +97,7 @@ class SyL_ControllerCmd extends SyL_Controller
     {
         $config_file = array();
         // ե
-        $config_file['actions'][] = SYL_APP_DIR . "/{$this->action_file_name}";
+        $config_file['actions'][] = SYL_APP_CONFIG_DIR . "/{$this->action_file_name}";
 
         // ٥ȼ¹
         $this->raiseEvent('executeStream', $config_file);
