@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataWeb.php,v 1.4 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataWeb.php,v 1.5 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataWeb.php,v 1.4 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataWeb.php,v 1.5 2007/08/12 05:59:50 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DataWeb extends SyL_Data
@@ -65,6 +65,10 @@ class SyL_DataWeb extends SyL_Data
         if (get_magic_quotes_gpc()) {
             $this->apply('stripslashes');
         }
+        // ʸɥåɲ
+        if (function_exists('mb_check_encoding')) {
+            $this->applyCheckEncodingRecursive($this->input_parameters, SYL_ENCODE_INTERNAL);
+        }
     }
 
     /**
