@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.5 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.6 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorJs.php,v 1.5 2007/05/20 09:43:02 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorJs.php,v 1.6 2007/05/27 16:24:29 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorJs extends SyL_Error
@@ -56,7 +56,7 @@ class SyL_ErrorJs extends SyL_Error
         $error_message = '';
         if (ini_get('display_errors')) {
             // 顼å
-            $error_message = implode($this->eof, $error_messages);
+            $error_message = implode($this->eol, $error_messages);
         }
 
         SyL_Response::setStatusHeader('500');
