@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.18 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.19 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.18 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_RouterPathinfo.php,v 1.19 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_RouterPathinfo extends SyL_Router
@@ -72,7 +72,7 @@ class SyL_RouterPathinfo extends SyL_Router
         } else {
             // ĥȽ
             if ($this->url_ext && !preg_match('/^(.+)(' . preg_quote($this->url_ext) . ')$/', $pathinfo)) {
-                SyL_Response::redirect404();
+                SyL_Response::forward404();
             }
             $pathinfo_file  = basename($pathinfo);
             $pathinfo_dir   = dirname($pathinfo);
