@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.8 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.9 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,7 +48,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Loader.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Context.php,v 1.8 2007/07/29 08:55:00 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Context.php,v 1.9 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Context
@@ -70,13 +70,6 @@ class SyL_Context
       'class' => '',
       'file'  => ''
     );
-    /**
-     * ե륿󥿡ե᥽å̾
-     * 
-     * @access private
-     * @var string
-     */
-    var $filter_method = 'affect';
     /**
      * ӥ塼
      * 
@@ -269,7 +262,7 @@ class SyL_Context
         // ƥץ졼ȥե¸ߥå
         if (!is_file($template_dir . $template_file)) {
             SyL_Loggers::warn("[Context] Template file not found dir: {$template_dir} file: {$template_file}");
-            SyL_Response::redirect404();
+            SyL_Response::forward404();
         }
         return $template_file;
     }
@@ -340,7 +333,8 @@ class SyL_Context
      */
     function &getComponent($name)
     {
-        return $this->controller->container->getComponent($name);
+        $container =& $this->controller->getContainer();
+        return $container->getComponent($name);
     }
 
     /**
