@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.26 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.27 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -69,7 +69,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.26 2007/08/08 12:25:20 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.27 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -174,37 +174,43 @@ class SyL_Controller
 
         // 󥭡
         define('SYL_ACTION_KEY', (isset($config['action_key']) && $config['action_key']) ? $config['action_key'] : 'action');
-        // ǥХå٥
-        define('SYL_DEBUG', (isset($config['debug']) && is_numeric($config['debug'])) ? $config['debug'] : SYL_LOG_WARN);
         // ץȥǥ쥯ȥ
-        define('SYL_PROJECT_DIR', (isset($config['webapp_dir']) && $config['webapp_dir']) ? $config['webapp_dir'] : SYL_DIR . '/webapp');
+        define('SYL_PROJECT_DIR', (isset($config['project_dir']) && $config['project_dir']) ? $config['project_dir'] : SYL_DIR . '/webapp');
         // ץեǥ쥯ȥ
         define('SYL_PROJECT_CONFIG_DIR',  SYL_PROJECT_DIR . '/config');
         // ץȥ饤֥ǥ쥯ȥ
         define('SYL_PROJECT_LIB_DIR',  SYL_PROJECT_DIR . '/lib');
         // ץꥱǥ쥯ȥ
-        define('SYL_APP_DIR', SYL_PROJECT_DIR . '/app/' . $config['app_name']);
+        define('SYL_APP_DIR', SYL_PROJECT_DIR . '/apps/' . $config['app_name']);
+        // ץꥱեǥ쥯ȥ
+        define('SYL_APP_CONFIG_DIR', SYL_APP_DIR . '/config');
 
         // å
         define('SYL_CACHE', (isset($config['cache']) && $config['cache']) ? $config['cache'] : false);
         switch (SYL_CACHE) {
         case 'file':
-            if (!isset($config['cache_dir']) || !$config['cache_dir']) {
-                trigger_error("[SyL error] Undefined cache file directory in initialise parameter `cache_dir'", E_USER_ERROR);
+            if (isset($config['cache_dir']) && $config['cache_dir']) {
+                define('SYL_CACHE_FILE_DIR', SYL_PROJECT_DIR . $config['cache_dir']);
+            } else {
+                define('SYL_CACHE_FILE_DIR', SYL_PROJECT_DIR . '/var/cache/');
             }
-            define('SYL_CACHE_FILE_DIR', SYL_PROJECT_DIR . $config['cache_dir']);
             break;
         case 'memcache':
-            if (!isset($config['cache_host']) || !$config['cache_host']) {
-                trigger_error("[SyL error] Undefined memcache host in initialise parameter `cache_host'", E_USER_ERROR);
+            if (isset($config['cache_host']) && $config['cache_host']) {
+                define('SYL_CACHE_MEMCACHE_HOST', $config['cache_host']);
+            } else {
+                define('SYL_CACHE_MEMCACHE_HOST', 'localhost:11211');
             }
-            define('SYL_CACHE_MEMCACHE_HOST', $config['cache_host']);
             break;
         }
 
         // ɤ߹
-        if (isset($config['define']) && $config['define']) {
-            $this->readDefines($config['define']);
+        if (isset($config['define_before']) && isset($config['define_after'])) {
+            $this->readDefines($config['define_before'], $config['define_after']);
+        } else if (isset($config['define_before']) && $config['define_before']) {
+            $this->readDefines($config['define_before'], '');
+        } else if (isset($config['define_after']) && $config['define_after']) {
+            $this->readDefines('', $config['define_after']);
         } else {
             $this->readDefines();
         }
@@ -255,26 +261,42 @@ class SyL_Controller
         return $singleton;
     }
 
+    /**
+     * ƥʤ
+     *
+     * @access public
+     * @return object ƥʥ֥
+     */
+    function &getContainer()
+    {
+        return $this->container;
+    }
+
     /**
      * ɤ߹
      *
      * @access public
      * @param array ɲե
      */
-    function readDefines($defines=array())
+    function readDefines($define_before='', $define_after='')
     {
         $config_files = array();
-        // ץꥱͤɤ߹
-        $config_files[] = SYL_APP_DIR . "/{$this->defines_file_name}";
+        // ɲե - ɤ߹
+        if ($define_before) {
+            $config_files[] = $define_before;
+        }
+         // ץꥱͤɤ߹
+        $config_files[] = SYL_APP_CONFIG_DIR . "/{$this->defines_file_name}";
         if (!file_exists($config_files[0])) {
             array_shift($config_files);
         }
         // Хͤɤ߹
         $config_files[] = SYL_PROJECT_CONFIG_DIR . "/{$this->defines_file_name}";
-        // ɲե
-        foreach ($defines as $define) {
-            $config_files[] = $define;
+        // ɲե - ɤ߹
+        if ($define_after) {
+            $config_files[] = $define_after;
         }
+
         $config =& SyL_Config::factory('defines', $config_files, $this);
         $config->parseXml();
     }
@@ -354,7 +376,7 @@ class SyL_Controller
     function finalStream()
     {
         // ̥ǥХå
-        if (class_exists('SyL_Loggers') && function_exists('memory_get_usage')) {
+        if (function_exists('memory_get_usage') && class_exists('SyL_Loggers')) {
             $debug = '[Controller] Memory Status  current: ' . number_format(floor(memory_get_usage()/1024)) . 'KB';
             if (function_exists('memory_get_peak_usage')) {
                 $debug .= ' max: ' . number_format(floor(memory_get_peak_usage()/1024)) . 'KB';
