@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loader.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loader.php,v 1.3 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loader.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loader.php,v 1.3 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Loader
@@ -55,9 +55,10 @@ class SyL_Loader
      * @static
      * @access public
      * @param string ɥե
+     * @param bool 顼٥ȥե饰
      * @return mixed include_once
      */
-    function lib($path)
+    function lib($path, $trigger=true)
     {
         $classname = __CLASS__;
 
@@ -75,7 +76,11 @@ class SyL_Loader
             return call_user_func(array($classname, 'load'), $base2);
         }
 
-        trigger_error("[SyL error] Library file not found ({$base1} or {$base2})", E_USER_ERROR);
+        if ($trigger) {
+            trigger_error("[SyL error] Library file not found ({$base1} or {$base2})", E_USER_ERROR);
+        } else {
+            return false;
+        }
     }
 
     /**
@@ -84,9 +89,10 @@ class SyL_Loader
      * @static
      * @access public
      * @param string ɥե
+     * @param bool 顼٥ȥե饰
      * @return mixed include_once
      */
-    function fw($path)
+    function fw($path, $trigger=true)
     {
         $classname = __CLASS__;
 
@@ -96,7 +102,11 @@ class SyL_Loader
             return call_user_func(array($classname, 'load'), $base1);
         }
 
-        trigger_error("[SyL error] Framework file not found ({$base1})", E_USER_ERROR);
+        if ($trigger) {
+            trigger_error("[SyL error] Framework file not found ({$base1})", E_USER_ERROR);
+        } else {
+            return false;
+        }
     }
 
     /**
@@ -156,10 +166,14 @@ class SyL_Loader
      * @static
      * @access public
      * @param string ѥ
+     * @param bool 󥯥롼ɥե饰
      * @return string 饹̾
      */
-    function convertClass($path)
+    function convertClass($path, $load=false)
     {
+        if ($load) {
+            call_user_func(array(__CLASS__, 'lib'), $path);
+        }
         return implode('', array_map('ucfirst', explode('.', $path)));
     }
 
