@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.22 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.23 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.22 2007/05/15 15:36:58 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.23 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -221,7 +221,7 @@ class SyL_View
     {
         $values  = array();
         $values += $this->context->getParameters();
-        $values += $this->data->getOutputParameters();
+        $values += $this->data->gets();
 
         return $values;
     }
