@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.8 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.9 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.8 2007/04/30 13:15:56 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.9 2007/05/20 09:43:02 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJson extends SyL_View
@@ -55,12 +55,16 @@ class SyL_ViewJson extends SyL_View
         $this->setContentType('application/json; charset=' . SYL_ENCODE_AJAX);
 
         if ($this->context->getActionName() != '') {
+            $values =& $this->getActionValues();
             // ѥ᡼ϡJson֥Ȥ򥻥å
             if (!function_exists('json_encode')) {
                 include_once SYL_INCLUDE_DIR . '/lib/Util/SyL_UtilJson.php';
+                $javascript = json_encode($values);
+            } else {
+                mb_convert_variables(SYL_ENCODE_AJAX, SYL_ENCODE_INTERNAL, $values);
+                $javascript = json_encode($values);
+                $javascript = mb_convert_encoding($javascript, SYL_ENCODE_INTERNAL, SYL_ENCODE_AJAX);
             }
-            $values     =& $this->getActionValues();
-            $javascript = json_encode($values);
             // JavaScirpt
             $this->setRender($javascript);
         }
