@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDriverMysql.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDriverMysql.php,v 1.3 2007/07/29 08:54:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DBDriverMysql.php,v 1.2 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DBDriverMysql.php,v 1.3 2007/07/29 08:54:59 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DBDriverMysql extends SyL_DB
@@ -357,9 +357,13 @@ class SyL_DBDriverMysql extends SyL_DB
         $pager = $this->getPager($limit, $page);
         // SQL
         if ($this->ismore41) {
-            $sql_count = "SELECT COUNT(*) FROM (" . $sql . ") AS SyL$";
+            $sql_count = "SELECT COUNT(*) FROM ({$sql}) AS SyL$";
         } else {
-            trigger_error("[SyL error] " . __FUNCTION__ . " method MySQL ver 4.1 more only", E_USER_ERROR);
+            if (preg_match('/^select (.+) from (.+)$/i', $sql, $matches)) {
+                $sql_count = "SELECT COUNT(*) FROM {$matches[2]}";
+            } else {
+                trigger_error("[SyL error] Invalid select SQL ({$sql})", E_USER_ERROR);
+            }
         }
         // SQL¹
         if (!$this->queryRef($sql_count, $record, 'one')) return false;
