@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.19 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.20 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once 'DB/SyL_DBSchema.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DB.php,v 1.19 2007/08/08 12:25:21 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DB.php,v 1.20 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_DB
@@ -778,7 +778,8 @@ class SyL_DB
     function getErrorMessage()
     {
         if ($this->errorInfo()) {
-            return $error_message = "[SyL DB Error " . $this->errorCode() . "] " . $this->errorInfo() . "<br>\n----------<br>\n{$this->last_sql}<br>\n----------<br>\n";
+            $eol = (PHP_SAPI == 'cli') ? "\n" : '<br>';
+            return $error_message = "[SyL DB Error " . $this->errorCode() . "] " . $this->errorInfo() . "{$eol}----------{$eol}{$this->last_sql}{$eol}----------{$eol}";
         } else {
             return '';
         }
