@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.13 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.14 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -48,11 +48,18 @@ require_once 'SyL_Validation.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.13 2007/07/08 04:22:38 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.14 2007/07/29 08:55:00 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Form
 {
+    /**
+     * ե̾
+     * 
+     * @access protected
+     * @var string
+     */
+    var $name = 'syl_form';
     /**
      * ե°
      *
@@ -122,14 +129,13 @@ class SyL_Form
      * 󥹥ȥ饯
      *
      * @access public
-     * @param string ե̾
+     * @param string ꥯȥ
      * @param string ꥯȥ᥽å
-     * @param string ꥯURL
      */
-    function SyL_Form($name="syl_form", $action=null, $method='POST')
+    function SyL_Form($action='', $method='POST')
     {
-        $this->setAttribute('name',   $name);
-        $this->setAttribute('id',     $name);
+        $this->setAttribute('name',   $this->name);
+        $this->setAttribute('id',     $this->name);
         $this->setAttribute('method', strtoupper($method));
         $this->setAttribute('action', $action ? $action : $_SERVER['PHP_SELF']);
 
@@ -216,7 +222,7 @@ class SyL_Form
      * @access public
      * @param mixed ѥ᡼ؿ
      */
-    function setInputCallback($callback)
+    function registerInputCallback($callback)
     {
         if (is_callable($callback)) {
             $this->input_callback = $callback;
