@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.2 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: CreateApplication.php,v 1.1 2007/07/29 08:54:59 seasonstream Exp $
+ * @version   CVS: $Id: CreateApplication.php,v 1.2 2007/08/27 06:00:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class CreateApplication
@@ -53,7 +53,7 @@ class CreateApplication
      */
     function trigger($project_dir, $app_name)
     {
-        $app_dir = "{$project_dir}app/{$app_name}/";
+        $app_dir = "{$project_dir}apps/{$app_name}/";
         if (!is_dir($app_dir)) {
             echo "  creating directory {$app_dir}\n"; ob_flush();
             if (!mkdir($app_dir, 0755)) {
@@ -64,16 +64,17 @@ class CreateApplication
 
         $dirs = array(
           'actions'   => 0755,
+          'config'    => 0755,
+          'lib'       => 0755,
           'templates' => 0755
         );
 
         $files = array(
-          'actions.xml'     => 'actions.xml',
-          'defines_app.xml' => 'defines.xml',
-          'filters.xml'     => 'filters.xml',
-          'layouts.xml'     => 'layouts.xml',
-          'CommonPreAction.php'  => 'CommonPreAction.php',
-          'CommonPostAction.php' => 'CommonPostAction.php'
+          'actions.xml'     => 'config/actions.xml',
+          'defines_app.xml' => 'config/defines.xml',
+          'filters.xml'     => 'config/filters.xml',
+          'layouts.xml'     => 'config/layouts.xml',
+          'AppAction.php'   => 'AppAction.php'
         );
 
         foreach ($dirs as $dir => $mode) {
